%%
%% This is file `ppnull.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% pdfpages.dtx  (with options: `ppnulldef')
%% 
%% This file is part of the pdfpages package.
%% 
%% Copyright (C) 2001-2025 Andreas MATTHIAS
%%
%% This work may be distributed and/or modified under the conditions
%% of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   <http://www.latex-project.org/lppl.txt>.
%%
%% This work has the LPPL maintenance status `maintained'.
%%
%% The Current Maintainer of this work is
%%   Andreas Matthias <andreas.matthias@gmail.com>.
%%
%% Please send error reports and suggestions for improvements to
%%   Andreas MATTHIAS <andreas.matthias@gmail.com>.
%%
\def\AM@git@tag{v0.6g}
\def\AM@git@date{2025/07/23}
\def\AM@git@hash{b55a30b6b0}
\ProvidesFile{ppnull.def}
   [\AM@git@date\space\AM@git@tag\space
    Pdfpages dummy driver (AM)]
\AM@DVIoutputtrue
\PackageWarningNoLine{pdfpages}{%
  I will use a dummy \string\includepdf\space command\MessageBreak
  which will insert empty pages instead of the actual\MessageBreak
  PDF file because we are running in \ifAM@pkg@demo `demo' mode%
  \else DVI mode or with\MessageBreak dvips driver%
  \fi}
\def\AM@findfile#1{%
  \def\AM@currentdocname{#1}%
}
\let\AM@IfFileExists\IfFileExists
\def\AM@getpagecount{%
  \ifx\AM@pagecount\AM@undefined
    \PackageWarningNoLine{pdfpages}{%
      I cannot determine the number of pages of the\MessageBreak
      included document, because we are running in\MessageBreak
      \ifAM@pkg@demo `demo' mode.
      \else DVI mode.
      \fi
      \MessageBreak
      You can use the option `lastpage' to give me a hint}%
    \edef\AM@pagecount{1}%
  \fi
}
\def\AM@getpagedimen{%
  \AM@pagewidth=\paperwidth
  \AM@pageheight=\paperheight
}
\def\AM@setpagedimen{%
  \paperwidth\AM@pagewidth
  \paperheight\AM@pageheight
}
\let\AM@pagesize@boogie\relax
\let\AM@fitpaper@special\relax
\def\AM@findfile#1{%
  \def\AM@currentdocname{}%
}
\let\AM@setlscape\relax
\let\AM@linktodoc@special@begin\relax
\let\AM@linktodoc@special@end\relax
\let\AM@survey@special@begin\relax
\let\AM@survey@special@end\relax
\let\AM@thread@special@begin\relax
\let\AM@thread@special@end\relax
\def\AM@reset@view{%
  \def\AM@view{}%
  \def\AM@view@xpos{0}%
  \def\AM@view@ypos{}}
\let\AM@dest@special\relax
\let\AM@anchor@special\relax
\def\AM@convert@dest#1{}
\def\AM@disable@includegraphics{%
  \renewcommand\includegraphics[2][]{}%
}
\newcommand*{\AM@checkpagenumber}[1]{}
\endinput
%%
%% End of file `ppnull.def'.
