%%
%% This is file `eu1enc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% euenc.dtx  (with options: `eu1')
%% 
%%   _____________________________________
%%   The EUENC bundle
%%   Will Robertson, Elie Roux, Khaled Hosny
%% 
%%   License information appended.
%% 
\ProvidesFile{eu1enc.def}
    [2010/05/27 v0.1h Experimental Unicode font encodings]
\DeclareFontEncoding{EU1}{}{}
\DeclareErrorFont{EU1}{lmr}{m}{n}{10}
\DeclareFontSubstitution{EU1}{lmr}{m}{n}
\g@addto@macro\nfss@catcodes{\@makeother:}
%% 
%% Copyright 2006-2010 Will Robertson <wspr81@gmail.com>
%% Copyright 2009-2010 Elie Roux <elie.roux@telecom-bretagne.eu>
%% Copyright 2009-2010 Khaled Hosny <khaledhosny@eglug.org>
%% 
%% Distributable under the LaTeX Project Public License,
%% version 1.3c or higher (your choice). The latest version of
%% this license is at: http://www.latex-project.org/lppl.txt
%% 
%% This work is "maintained" (as per LPPL maintenance status)
%% by Will Robertson.
%% 
%% This work consists of the file  euenc.dtx and various derived files.
%% 
%%
%% End of file `eu1enc.def'.
